0.2.16 (2023-06-04)
-------------------

Finished support for SPA themes (comments and podlove player).

* Made comments data available via wagtail api #95
* Made some data available just via page attribute, because it's only added via template and script tag #95
